@@ -55,6 +55,9 @@ te_dp_event kword_tkns[] = { KEYWORD_TABLE };
 static void
 pop_context(void);
 
+static int
+count_nl(char const * pz);
+
 static void
 trim_whitespace(void);
 
@@ -98,6 +101,26 @@ pop_context(void)
     end_ctx       = pCX;
 }
 
+/**
+ * Count the newlines in a NUL terminated string
+ */
+static int
+count_nl(char const * pz)
+{
+    int ct = 0;
+    for (;;) {
+        char const * p = strchr(pz, NL);
+        if (p == NULL)
+            break;
+        ct++;
+        pz = p + 1;
+    }
+    return ct;
+}
+
+/**
+ * Remove leading white space from the current scan point.
+ */
 static void
 trim_whitespace(void)
 {
@@ -560,8 +583,8 @@ alist_to_autogen_def(void)
 }
 
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/**
  *  It may be a number, a name, a keyword or garbage.
  *  Figure out which.
  */
@@ -569,13 +592,19 @@ static char*
 gather_name(char * scan, te_dp_event * ret_val)
 {
     /*
-     *  Check for a number.
-     *  Scan it in and advance "scan".
+     *  Check for a number.  We don't care about leading zeros, that
+     *  is a user's problem, so no distinction between octal and decimal.
+     *  However, we look for "0x" and "0X" prefixes for hex numbers.
      */
     if (  IS_DEC_DIGIT_CHAR(*scan)
        || ((*scan == '-') && IS_DEC_DIGIT_CHAR(scan[1])) ) {
         token_str = scan;
         *ret_val  = DP_EV_NUMBER;
+
+        if (  (scan[0] == '0')
+           && ((scan[1] == 'x') || (scan[1] == 'X')) )
+            return SPN_HEX_DIGIT_CHARS(scan + 2);
+
         return SPN_DEC_DIGIT_CHARS(scan + 1);
     }
 
