@@ -8,7 +8,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -48,7 +48,9 @@ load_file(char const * fname)
     {
         struct stat stbf;
         if (fstat(fileno(fp), &stbf) != 0) {
+            int err = errno;
             fclose(fp);
+            errno = err;
             return NULL;
         }
 
@@ -62,11 +64,8 @@ load_file(char const * fname)
         char * scan = res;
         do  {
             size_t sz = fread(scan, 1, fsz, fp);
-            if (sz == 0) {
-                fprintf(stderr, LD_EXTRACT_BAD_READ, errno, strerror(errno),
-                        (int)fsz, fname);
-                AG_ABEND(LD_EXTRACT_READ_FAIL);
-            }
+            if (sz == 0)
+                fserr(AUTOGEN_EXIT_FS_ERROR, "fread", fname);
 
             scan += sz;
             fsz  -= sz;
@@ -162,13 +161,13 @@ mk_empty_text(char const * start, char const * end, SCM def)
     char * pzOut;
 
     if (! AG_SCM_STRING_P(def)) {
-        pzOut = ag_scribble(mlen);
+        pzOut = scribble_get(mlen);
         sprintf(pzOut, LINE_CONCAT3_FMT+3, start, end);
 
     } else {
         char const * pzDef = ag_scm2zchars(def, "dft extr str");
         mlen += (ssize_t)AG_SCM_STRLEN(def) + 1;
-        pzOut = ag_scribble(mlen);
+        pzOut = scribble_get(mlen);
         sprintf(pzOut, LINE_CONCAT3_FMT, start, pzDef, end);
     }
 
